@@ -1,13 +1,6 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import
 
-from sys import version_info
-
-if version_info[:2] >= (3, 0):
-    try:
-        import ampltools as tools
-    except:
-        tools = None
 
 from .base import BaseClass
 from .outputhandler import OutputHandler, Kind
@@ -22,11 +15,20 @@ from .set import Set
 from .parameter import Parameter
 from .entity import Entity
 from .dataframe import DataFrame, Row, Column
-from .utils import multidict, register_magics
+from .utils import add_to_path, multidict, register_magics
 from .environment import Environment
 from .ampl import AMPL
 
-__version__ = "0.8.5"
+try:
+    from ampltools import register_magics
+except Exception:
+    pass
+try:
+    from ampltools import add_to_path
+except Exception:
+    pass
+
+__version__ = "0.8.6"
 
 
 def _list_aliases():
