@@ -56,7 +56,7 @@ class EntityMap {
     /**
      * Regular constructor
      */
-    explicit iterator(internal::EntityMap_RefPointer<EntityInner>* it)
+    explicit iterator(internal::EntityMapRefPointer<EntityInner>* it)
         : data_(it) {}
 
     /**
@@ -130,7 +130,7 @@ class EntityMap {
     }
 
    private:
-    internal::EntityMap_RefPointer<EntityInner>* data_;
+    internal::EntityMapRefPointer<EntityInner>* data_;
 
     void destroy() {
       if (data_ != NULL) {
