@@ -56,12 +56,13 @@ class Environment {
   will not be executed.
   \endrst
   \param binaryDirectory The directory in which look for the %AMPL Binary
+  \param binaryName The name of the %AMPL executable if other than "ampl"
   */
-  explicit Environment(fmt::CStringRef binaryDirectory) {
-    impl_ = internal::AMPL_Environment_Create_WithBin(binaryDirectory.c_str(),
-                                                      internal::ErrorInfo());
+  explicit Environment(fmt::CStringRef binaryDirectory,
+                       fmt::CStringRef binaryName = "") {
+    impl_ = internal::AMPL_Environment_Create_WithBin(
+        binaryDirectory.c_str(), binaryName.c_str(), internal::ErrorInfo());
   }
-
   /**
    * Destructor
    */
@@ -95,6 +96,23 @@ class Environment {
         impl_, internal::ErrorInfo()));
   }
 
+  /**
+   * Set the name of the %AMPL executable
+   * \param binaryName Executable
+   */
+  void setBinName(fmt::CStringRef binaryName) {
+    internal::AMPL_Environment_setBinaryName(impl_, binaryName.c_str(),
+                                             internal::ErrorInfo());
+  }
+
+  /**
+   * Get the name of the %AMPL executable
+   */
+  std::string getBinName() const {
+    return std::string(
+        internal::AMPL_Environment_getBinaryName(impl_, internal::ErrorInfo()));
+  }
+
   /**
   \rst
   Print all variables in the map
