@@ -23,9 +23,12 @@ class Parameter;
 class Instance;
 class Table;
 
-struct Entity_RefPointer {
-  std::size_t count;
-  std::map<TupleRef, Instance *>::iterator it;
+struct EntityRefPointer {
+  std::size_t count_;
+  std::map<TupleRef, Instance *>::iterator it_;
+  EntityRefPointer(size_t count,
+                   const std::map<TupleRef, Instance *>::iterator &it)
+      : count_(count), it_(it) {}
 };
 
 extern "C" {
@@ -62,19 +65,19 @@ AMPLAPI std::size_t AMPL_Entity_numInstances(EntityBase *impl,
 AMPLAPI const Tuple *AMPL_Entity_getTuples(EntityBase *impl, std::size_t *size);
 
 // ************* Iterators *************
-AMPLAPI Tuple AMPL_Entity_iterator_getPointer(Entity_RefPointer *it1,
+AMPLAPI Tuple AMPL_Entity_iterator_getPointer(EntityRefPointer *it1,
                                               Instance **instance);
-AMPLAPI Entity_RefPointer *AMPL_Entity_begin(EntityBase *impl,
-                                             ErrorInformation *errorInfo);
-AMPLAPI Entity_RefPointer *AMPL_Entity_end(EntityBase *impl,
+AMPLAPI EntityRefPointer *AMPL_Entity_begin(EntityBase *impl,
+                                            ErrorInformation *errorInfo);
+AMPLAPI EntityRefPointer *AMPL_Entity_end(EntityBase *impl,
+                                          ErrorInformation *errorInfo);
+AMPLAPI EntityRefPointer *AMPL_Entity_find(EntityBase *impl, Tuple t,
                                            ErrorInformation *errorInfo);
-AMPLAPI Entity_RefPointer *AMPL_Entity_find(EntityBase *impl, Tuple t,
+AMPLAPI void AMPL_Entity_iterator_increment(EntityRefPointer *it,
                                             ErrorInformation *errorInfo);
-AMPLAPI void AMPL_Entity_iterator_increment(Entity_RefPointer *it,
-                                            ErrorInformation *errorInfo);
-AMPLAPI void AMPL_Entity_iterator_delete(Entity_RefPointer *it);
-AMPLAPI bool AMPL_Entity_iterator_equal(Entity_RefPointer *it1,
-                                        Entity_RefPointer *it2,
+AMPLAPI void AMPL_Entity_iterator_delete(EntityRefPointer *it);
+AMPLAPI bool AMPL_Entity_iterator_equal(EntityRefPointer *it1,
+                                        EntityRefPointer *it2,
                                         ErrorInformation *errorInfo);
 
 // ************* Variable *************
@@ -88,8 +91,8 @@ AMPLAPI void AMPL_Variable_setValue(Variable *impl, double value,
                                     ErrorInformation *errorInfo);
 
 // *************  Parameter *************
-AMPLAPI Tuple AMPL_Parameter_iterator_getPointer(Entity_RefPointer *it1,
-                                                 Variant *instance);
+AMPLAPI Tuple AMPL_Parameter_iterator_getPointer(EntityRefPointer *it1,
+                                                 Variant **instance);
 
 AMPLAPI void AMPL_Parameter_setValues(Parameter *impl, Tuple indices[],
                                       AMPLArgs values, std::size_t nvalues,
@@ -153,7 +156,7 @@ class EntityWrapper {
   typedef std::pair<TupleRef, InstanceClass> ValueType;
   typedef TupleRef KeyType;
   typedef InstanceClass InstanceType;
-  typedef internal::Entity_RefPointer *ReferencePointer;
+  typedef internal::EntityRefPointer *ReferencePointer;
 
   static void dispose(ReferencePointer data) {
     internal::AMPL_Entity_iterator_delete(data);
@@ -166,8 +169,9 @@ class EntityWrapper {
     AMPL_Entity_iterator_increment(it, internal::ErrorInfo());
   }
   static ValueType getPointer(ReferencePointer it) {
-    Instance *instance;
-    Tuple t = internal::AMPL_Entity_iterator_getPointer(it, &instance);
+    internal::Instance *instance;
+    internal::Tuple t =
+        internal::AMPL_Entity_iterator_getPointer(it, &instance);
     return ValueType(TupleRef(t), InstanceClass(instance));
   }
 
@@ -199,7 +203,7 @@ class EntityWrapper<VariantRef> {
   typedef std::pair<TupleRef, ampl::VariantRef> ValueType;
   typedef VariantRef InstanceType;
   typedef TupleRef KeyType;
-  typedef internal::Entity_RefPointer *ReferencePointer;
+  typedef internal::EntityRefPointer *ReferencePointer;
 
   static void dispose(ReferencePointer data) {
     internal::AMPL_Entity_iterator_delete(data);
@@ -213,8 +217,9 @@ class EntityWrapper<VariantRef> {
   }
 
   static ValueType getPointer(ReferencePointer it) {
-    internal::Variant instance;
-    Tuple t = internal::AMPL_Parameter_iterator_getPointer(it, &instance);
+    internal::Variant *instance;
+    internal::Tuple t =
+        internal::AMPL_Parameter_iterator_getPointer(it, &instance);
     return ValueType(TupleRef(t), VariantRef(instance));
   }
 
