@@ -1,12 +1,15 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function, absolute_import, division
-from builtins import map, range, object, zip, sorted
-from past.builtins import basestring
+
+# from builtins import map, range, object, zip, sorted
+from builtins import map
+
+# from past.builtins import basestring
 
 from .base import BaseClass
-from .utils import Utils, Tuple
 from .dataframe import DataFrame
 from .iterators import InstanceIterator
+
 try:
     import pandas as pd
 except ImportError:
@@ -25,7 +28,7 @@ class Entity(BaseClass):
 
     To gain access to all the values in an entity (for all instances and all
     suffixes for that entities), use the function
-    :func:`~amplpy.Entity.getValues`.
+    :func:`~amplpy.Entity.get_values` / :func:`~amplpy.Entity.getValues`.
 
     The algebraic entities which currenty have an equivalent class in the API
     are:
@@ -37,13 +40,13 @@ class Entity(BaseClass):
     - Parameters (see :class:`~amplpy.Parameter`)
     """
 
-    def __init__(self, _impl, wrapFunction=None):
+    def __init__(self, _impl, wrap_function=None):
         BaseClass.__init__(self, _impl)
-        self.wrapFunction = wrapFunction
+        self.wrap_function = wrap_function
 
     def __iter__(self):
-        assert self.wrapFunction is not None
-        return InstanceIterator(self._impl, self.wrapFunction)
+        assert self.wrap_function is not None
+        return InstanceIterator(self._impl, self.wrap_function)
 
     def __getitem__(self, index):
         if not isinstance(index, (tuple, list)):
@@ -51,11 +54,7 @@ class Entity(BaseClass):
         return self.get(*index)
 
     def __setitem__(self, index, value):
-        item = self.__getitem__(index)
-        if isinstance(value, (float, int, basestring)):
-            item.set(value)
-        else:
-            item.setValues(value)
+        self.__getitem__(index).set_values(value)
 
     def get(self, *index):
         """
@@ -64,13 +63,13 @@ class Entity(BaseClass):
         Returns:
             The corresponding instance.
         """
-        assert self.wrapFunction is not None
+        assert self.wrap_function is not None
         if len(index) == 1 and isinstance(index[0], (tuple, list)):
             index = index[0]
         if len(index) == 0:
-            return self.wrapFunction(self._impl.get())
+            return self.wrap_function(self._impl.get())
         else:
-            return self.wrapFunction(self._impl.get(Tuple(index)._impl))
+            return self.wrap_function(self._impl.get(index))
 
     def find(self, *index):
         """
@@ -79,20 +78,20 @@ class Entity(BaseClass):
         Returns:
             The wanted instance if found, otherwise it returns `None`.
         """
-        assert self.wrapFunction is not None
+        assert self.wrap_function is not None
         if len(index) == 1 and isinstance(index[0], (tuple, list)):
             index = index[0]
-        it = self._impl.find(Tuple(index)._impl)
-        if it == self._impl.end():
+        iterator = self._impl.find(index)
+        if iterator == self._impl.end():
             return None
         else:
-            return self.wrapFunction(it)
+            return self.wrap_function(iterator.second())
 
     def instances(self):
         """
         Get all the instances in this entity..
         """
-        return InstanceIterator(self._impl, self.wrapFunction)
+        return InstanceIterator(self._impl, self.wrap_function)
 
     def name(self):
         """
@@ -121,7 +120,7 @@ class Entity(BaseClass):
         """
         return self._impl.indexarity()
 
-    def isScalar(self):
+    def is_scalar(self):
         """
         Check whether this entity is scalar. Equivalent to testing whether
         :func:`~amplpy.Entity.indexarity` is equal to zero.
@@ -131,13 +130,13 @@ class Entity(BaseClass):
         """
         return self._impl.isScalar()
 
-    def numInstances(self):
+    def num_instances(self):
         """
         Get the number of instances in this entity.
         """
         return self._impl.numInstances()
 
-    def getIndexingSets(self):
+    def get_indexing_sets(self):
         """
         Get the AMPL string representation of the sets on which this entity is
         indexed. The obtained vector can be modified without any effect to the
@@ -147,7 +146,7 @@ class Entity(BaseClass):
             The string representation of the indexing sets for this entity or
             an empty array if the entity is scalar.
         """
-        return Utils.castStringArray(self._impl.getIndexingSets())
+        return self._impl.getIndexingSets()
 
     def xref(self):
         """
@@ -156,9 +155,9 @@ class Entity(BaseClass):
         Returns:
             A list with the names of all entities which depend on this one.
         """
-        return Utils.castStringArray(self._impl.xref())
+        return self._impl.xref()
 
-    def getValues(self, suffixes=None):
+    def get_values(self, suffixes=None):
         """
         If a list of suffixes is provided, get the specified suffixes value for
         all instances. Otherwise, get all the principal values of this entity.
@@ -171,19 +170,22 @@ class Entity(BaseClass):
         - Sets it returns all the members of the set. Note that it does not
           apply to indexed sets. See :func:`~amplpy.Set.getValues`.
 
+        Raises:
+            RuntimeError: if there are issues with the data.
+
         Retruns:
             A :class:`~amplpy.DataFrame` containing the values for all
             instances.
         """
         if suffixes is None:
-            return DataFrame._fromDataFrameRef(self._impl.getValues())
+            return DataFrame._from_data_frame_ref(self._impl.getValues())
         else:
             suffixes = list(map(str, suffixes))
-            return DataFrame._fromDataFrameRef(
+            return DataFrame._from_data_frame_ref(
                 self._impl.getValuesLst(suffixes, len(suffixes))
             )
 
-    def setValues(self, data):
+    def set_values(self, data):
         """
         Set the values of this entiy to the correponding values of a
         DataFrame indexed over the same sets (or a subset).
@@ -207,10 +209,17 @@ class Entity(BaseClass):
         if isinstance(data, DataFrame):
             self._impl.setValuesDf(data._impl)
         elif isinstance(data, dict):
-            self._impl.setValuesDf(DataFrame.fromDict(data)._impl)
+            self._impl.setValuesDf(DataFrame.from_dict(data)._impl)
         else:
             if pd is not None and isinstance(data, (pd.DataFrame, pd.Series)):
-                df = DataFrame.fromPandas(data)
+                df = DataFrame.from_pandas(data)
                 self._impl.setValuesDf(df._impl)
                 return
             raise TypeError
+
+    # Aliases
+    getIndexingSets = get_indexing_sets
+    getValues = get_values
+    isScalar = is_scalar
+    numInstances = num_instances
+    setValues = set_values
