@@ -1,22 +1,24 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 from __future__ import print_function, absolute_import, division
-from builtins import map, range, object, zip, sorted
 
-from .context import amplpy
+# from builtins import map, range, object, zip, sorted
+
 import unittest
 import tempfile
 import shutil
 import os
+from .context import amplpy
 
 
 # For MSYS2, MINGW, etc., run with:
 # $ REAL_ROOT=`cygpath -w /` python -m amplpy.tests
-REAL_ROOT = os.environ.get('REAL_ROOT', None)
+REAL_ROOT = os.environ.get("REAL_ROOT", None)
 
 
 class TestBase(unittest.TestCase):
     def setUp(self):
+        print("Method:", self._testMethodName)
         self.ampl = amplpy.AMPL()
         self.dirpath = tempfile.mkdtemp()
 
@@ -25,14 +27,14 @@ class TestBase(unittest.TestCase):
 
     def _real_filename(self, filename):
         # Workaround for MSYS2, MINGW paths
-        if REAL_ROOT is not None and filename.startswith('/'):
-            filename = filename.replace('/', REAL_ROOT, 1)
+        if REAL_ROOT is not None and filename.startswith("/"):
+            filename = filename.replace("/", REAL_ROOT, 1)
         return filename
 
     def str2file(self, filename, content):
         fullpath = self._tmpfile(filename)
-        with open(fullpath, 'w') as f:
-            print(content, file=f)
+        with open(fullpath, "w") as file:
+            print(content, file=file)
         return self._real_filename(fullpath)
 
     def tmpfile(self, filename):
@@ -43,5 +45,5 @@ class TestBase(unittest.TestCase):
         shutil.rmtree(self.dirpath)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
